@@ -19,12 +19,12 @@ import os
 import os.path
 
 PACKAGE    = "sabayon"
-VERSION    = "2.29.91"
-LOCALEDIR  = "/usr/local/share/locale"
-DATADIR    = "/usr/local/share"
-SYSCONFDIR = "/usr/local/etc"
-LIBEXECDIR = "/usr/local/libexec"
-SBINDIR    = "/usr/local/sbin"
+VERSION    = "2.30.0"
+LOCALEDIR  = "/gnome/usr/share/locale"
+DATADIR    = "/gnome/usr/share"
+SYSCONFDIR = "/gnome/usr/etc"
+LIBEXECDIR = "/gnome/usr/libexec"
+SBINDIR    = "/gnome/usr/sbin"
 
 BUILDERDIR  = os.path.join (DATADIR,    "sabayon", "ui")
 CONFIGDIR   = os.path.join (SYSCONFDIR, "sabayon")
@@ -66,7 +66,7 @@ NOLOGIN_SHELL = "/sbin/nologin"
 SKEL_HOMEDIR  = "/etc/skel"
 
 XEPHYR_ARGV  = [ "/usr/bin/Xephyr", "-terminate", "-audit", "0", "-nolisten", "tcp", "-name", "sabayon" ]
-SESSION_ARGV = [ "/etc/gdm/Xsession", "gnome-session" ]
+SESSION_ARGV = [ "/etc/gdm/Xsession", "gnome" ]
 USERMOD_ARGV = [ "/usr/sbin/usermod" ]
 
 PANEL_KEY_BASE = "/apps/panel"
