@@ -65,12 +65,19 @@ class FilesChange (userprofile.ProfileChange):
 
     def get_short_description (self):
         utf8_rel_path = gobject.filename_display_name (self.rel_path)
+        if os.path.isdir(self.rel_path):
+            filetype = _("Directory")
+        elif os.path.islink(self.rel_path):
+            filetype = _("Link")
+        else:
+            filetype = _("File")
         if self.event == dirmonitor.CREATED:
-            return _("File '%s' created") % utf8_rel_path
+            return _("%s '%s' created") % (filetype, utf8_rel_path)
         elif self.event == dirmonitor.DELETED:
-            return _("File '%s' deleted") % utf8_rel_path
+            return _("%s '%s' deleted") % (filetype, utf8_rel_path)
         elif self.event == dirmonitor.CHANGED:
-            return _("File '%s' changed") % utf8_rel_path
+            return _("%s '%s' changed") % (filetype, utf8_rel_path)
+
 
 gobject.type_register (FilesChange)
 
@@ -83,6 +90,7 @@ class FilesSource (userprofile.ProfileSource):
                                                     self.__handle_monitor_event)
         self.monitor.set_directories_to_ignore (DIRECTORIES_TO_IGNORE)
         self.monitor.set_files_to_ignore (FILES_TO_IGNORE)
+        self.SORTPRIORITY = 500
 
     def __handle_monitor_event (self, path, event):
         if event == dirmonitor.DELETED or os.path.isfile (path) or os.path.isdir (path):
@@ -95,8 +103,8 @@ class FilesSource (userprofile.ProfileSource):
     def get_path_description (self, path):
         if path == ".config/menus/applications.menu":
             return _("Applications menu")
-        elif path == ".config/menus/preferences.menu":
-            return _("Preferences menu")
+        elif path == ".config/menus/settings.menu":
+            return _("Settings menu")
         elif path == ".config/menus/server-settings.menu":
             return _("Server Settings menu")
         elif path == ".config/menus/system-settings.menu":
@@ -177,7 +185,7 @@ def run_unit_tests ():
     def should_not_be_reached ():
         assert False
         return True
-    timeout = gobject.timeout_add (60 * 1000, should_not_be_reached)
+    timeout = gobject.timeout_add_seconds (60, should_not_be_reached)
 
     profile_path = os.path.join (os.getcwd (), "file-test.zip")
     if os.path.exists (profile_path):
