@@ -22,6 +22,8 @@ import tempfile, types
 import traceback
 import errno
 import time
+import getpass
+import subprocess
 
 try:
     import util
@@ -152,6 +154,7 @@ class MozillaDelegate(userprofile.SourceDelegate):
         self.committed_bookmarks = mozilla_bookmarks.BookmarkFolder("Null", None)
         self.committed_mandatory_bookmarks = mozilla_bookmarks.BookmarkFolder("Null", None)
         self.ini_file = None
+        self.SORTPRIORITY = 50
 
     def get_full_path(self, path):
         return os.path.join(self.home_dir, path)        
@@ -390,9 +393,20 @@ class MozillaDelegate(userprofile.SourceDelegate):
         dprint(LOG_APPLY, "apply: ini_files=%s pref_files=%s bookmark_files=%s other_files=%s",
                ini_files, pref_files, bookmark_files, other_files)
 
+        def which_firefox ():
+            path = os.environ['PATH']
+            paths = path.split(os.pathsep)
+            for p in paths:
+                f = os.path.join (p, "firefox")
+                if os.path.exists (f):
+                    return f
+            else:
+                return None
+
         # Profiles.ini file must be done first, if the target does not
         # exist then extract it from the profile.
         # Parse the profiles.ini file to learn the target profiles
+        # If no profile exists in homedir or .zip, create new profile
         self.load_profiles_ini()
         if not self.ini_file.is_valid():
             dprint(LOG_APPLY, "apply: no valid ini file, extracting %s", profiles_ini_rel_path)
@@ -400,7 +414,23 @@ class MozillaDelegate(userprofile.SourceDelegate):
                 self.source.storage.extract(profiles_ini_rel_path, self.home_dir, True)
                 self.load_profiles_ini()
             else:
-                dprint(LOG_APPLY, "apply: but there isn't an ini file in the profile!")
+                dprint(LOG_APPLY, "apply: but there isn't an ini file in the profile.  Creating new profile.")
+                firefoxpath = which_firefox ()
+                if firefoxpath:
+                    subprocess.call ([firefoxpath, "-createProfile", getpass.getuser ()])
+                    self.load_profiles_ini()
+                    # XXX: Temporary Workaround for Mozilla Bug #333479
+                    # Delete bookmarks.html created by firefox -createProfile
+                    for profile in self.ini_file.get_profiles():
+                        # There should only be one profile
+                        profile_rel_dir = profile.get_rel_dir()
+                        bogusbookmarks = os.path.join(profile_rel_dir, "bookmarks.html")
+                        if os.path.exists (bogusbookmarks):
+                            dprint (LOG_APPLY, "apply: Remove bogus file %s, see Mozilla Bug #333479.", bogusbookmarks)
+                            os.remove (bogusbookmarks)
+
+                else:
+                    dprint (APPLY, "apply: Firefox not found in PATH.  Unable to create new profile.")
 
         # --------------------
         if sabayon_pref_rel_path in pref_files:
@@ -970,6 +1000,8 @@ gobject.type_register(BookmarkChange)
 
 class BookmarksFile(FirefoxProfileFile):
     def __init__(self, home_dir, rel_path):
+        # XXX: It says it is created, but if it doesn't exist it does not.
+        # Rewrite this when we properly handle sqlite bookmarks.
         dprint(LOG_OPERATION, "BookmarksFile: created (%s)", rel_path)
         FirefoxProfileFile.__init__(self, home_dir, rel_path)
         self.parser = mozilla_bookmarks.BookmarkHTMLParser()
